@@ -17,9 +17,9 @@ from typing import Any, Dict, List, Type
 from botocore.client import ClientMeta
 
 from .type_defs import (
-    CreateTokenResponseTypeDef,
-    RegisterClientResponseTypeDef,
-    StartDeviceAuthorizationResponseTypeDef,
+    CreateTokenResponseResponseTypeDef,
+    RegisterClientResponseResponseTypeDef,
+    StartDeviceAuthorizationResponseResponseTypeDef,
 )
 
 __all__ = ("SSOOIDCClient",)
@@ -51,7 +51,7 @@ class Exceptions:
 
 class SSOOIDCClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/sso-oidc.html#SSOOIDC.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-oidc.html#SSOOIDC.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html)
     """
 
@@ -60,7 +60,9 @@ class SSOOIDCClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/sso-oidc.html#SSOOIDC.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-oidc.html#SSOOIDC.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#can_paginate)
         """
 
@@ -75,9 +77,11 @@ class SSOOIDCClient:
         refreshToken: str = None,
         scope: List[str] = None,
         redirectUri: str = None
-    ) -> CreateTokenResponseTypeDef:
+    ) -> CreateTokenResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/sso-oidc.html#SSOOIDC.Client.create_token)
+        Creates and returns an access token for the authorized client.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-oidc.html#SSOOIDC.Client.create_token)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#create_token)
         """
 
@@ -89,22 +93,29 @@ class SSOOIDCClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/sso-oidc.html#SSOOIDC.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-oidc.html#SSOOIDC.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#generate_presigned_url)
         """
 
     def register_client(
         self, *, clientName: str, clientType: str, scopes: List[str] = None
-    ) -> RegisterClientResponseTypeDef:
+    ) -> RegisterClientResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/sso-oidc.html#SSOOIDC.Client.register_client)
+        Registers a client with AWS SSO.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-oidc.html#SSOOIDC.Client.register_client)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#register_client)
         """
 
     def start_device_authorization(
         self, *, clientId: str, clientSecret: str, startUrl: str
-    ) -> StartDeviceAuthorizationResponseTypeDef:
+    ) -> StartDeviceAuthorizationResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.100/reference/services/sso-oidc.html#SSOOIDC.Client.start_device_authorization)
+        Initiates device authorization by requesting a pair of verification codes from
+        the authorization service.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-oidc.html#SSOOIDC.Client.start_device_authorization)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_oidc/client.html#start_device_authorization)
         """
